module.exports = {
	root: true,
	env: {
		node: true,
		browser: true,
		jest: true
	},
	extends: ['plugin:vue/essential', '@vue/prettier'],
	rules: {
		// 禁止条件表达式中出现赋值操作符
		'no-cond-assign': 'warn',
		// 禁止在条件中使用常量表达式
		'no-constant-condition': 'warn',
		// 禁用 debugger
		'no-debugger': 'warn',
		// 禁止 function 定义中出现重名参数
		'no-dupe-args': 'warn',
		// 禁止对象字面量中出现重复的 key
		'no-dupe-keys': 'error',
		// 禁止出现空语句块
		'no-empty': 'warn',
		// 禁止在正则表达式中使用空字符集
		'no-empty-character-class': 'warn',
		// 禁止不必要的布尔转换
		'no-extra-boolean-cast': 'warn',
		// 禁止不必要的分号
		'no-extra-semi': 'warn',
		// 禁止对 function 声明重新赋值
		'no-func-assign': 'warn',
		// 禁止在嵌套的块中出现变量声明或 function 声明
		'no-inner-declarations': 'warn',
		// 禁止 RegExp 构造函数中存在无效的正则表达式字符串
		'no-invalid-regexp': 'warn',
		// 禁止不规则的空白
		'no-irregular-whitespace': 'warn',
		// 不允许在字符类语法中出现由多个代码点组成的字符
		'no-misleading-character-class': 'warn',
		// 禁止把全局对象作为函数调用
		'no-obj-calls': 'warn',
		// 禁止直接调用 Object.prototypes 的内置属性
		'no-prototype-builtins': 'warn',
		// 禁止正则表达式字面量中出现多个空格
		'no-regex-spaces': 'warn',
		// 禁用稀疏数组
		'no-sparse-arrays': 'warn',
		// 禁止出现令人困惑的多行表达式
		'no-unexpected-multiline': 'warn',
		// 禁止在 return、throw、continue 和 break 语句之后出现不可达代码
		'no-unreachable': 'warn',
		// 禁止在 finally 语句块中出现控制流语句
		'no-unsafe-finally': 'warn',
		// 禁止对关系运算符的左操作数使用否定操作符
		'no-unsafe-negation': 'warn',
		// 禁止由于 await 或 yield的使用而可能导致出现竞态条件的赋值
		'require-atomic-updates': 'warn',
		// 要求使用 isNaN() 检查 NaN
		'use-isnan': 'warn',
		// 强制 typeof 表达式与有效的字符串进行比较
		'valid-typeof': 'warn',

		// 强制 getter 和 setter 在对象中成对出现
		'accessor-pairs': 'warn',
		// 强制数组方法的回调函数中有 return 语句
		'array-callback-return': 'warn',
		// 强制把变量的使用限制在其定义的作用域范围内
		'block-scoped-var': 'warn',
		// 要求 return 语句要么总是指定返回的值，要么不指定
		'consistent-return': 'warn',
		// 强制所有控制语句使用一致的括号风格
		curly: 'warn',
		// 要求 switch 语句中有 default 分支
		'default-case': 'warn',
		// 要求使用 === 和 !==
		eqeqeq: 'warn',
		// 强制每个文件中包含的的类的最大数量
		'max-classes-per-file': ['warn', 1],
		// 禁用 arguments.caller 或 arguments.callee
		'no-caller': 'warn',
		// 不允许在 case 子句中使用词法声明
		'no-case-declarations': 'warn',
		// 禁止除法操作符显式的出现在正则表达式开始的位置
		'no-div-regex': 'warn',
		// 禁止使用空解构模式
		'no-empty-pattern': 'warn',
		// 禁止在没有类型检查操作符的情况下与 null 进行比较
		'no-eq-null': 'warn',
		// 禁用 eval()
		'no-eval': 'warn',
		// 禁止扩展原生类型
		'no-extend-native': 'warn',
		// 禁止不必要的 .bind() 调用
		'no-extra-bind': 'warn',
		// 禁用不必要的标签
		'no-extra-label': 'warn',
		// 禁止 case 语句落空
		'no-fallthrough': 'warn',
		// 禁止数字字面量中使用前导和末尾小数点
		'no-floating-decimal': 'warn',
		// 禁止对原生对象或只读的全局对象进行赋值
		'no-global-assign': 'warn',
		// 	禁止使用短符号进行类型转换
		'no-implicit-coercion': 'warn',
		// 禁止使用类似 eval() 的方法
		'no-implied-eval': 'warn',
		// 禁止 this 关键字出现在类和类对象之外
		'no-invalid-this': 'warn',
		// 禁用 __iterator__ 属性
		'no-iterator': 'warn',
		// 禁用标签语句
		'no-labels': 'warn',
		// 禁用不必要的嵌套块
		'no-lone-blocks': 'warn',
		// 禁止使用多个空格
		'no-multi-spaces': 'warn',
		// 禁止使用多行字符串
		'no-multi-str': 'warn',
		// 禁止使用 new 以避免产生副作用
		'no-new': 'warn',
		// 禁止对 Function 对象使用 new 操作符
		'no-new-func': 'warn',
		// 禁止对 String，Number 和 Boolean 使用 new 操作符
		'no-new-wrappers': 'warn',
		// 禁用八进制字面量
		'no-octal': 'warn',
		// 禁止在字符串中使用八进制转义序列
		'no-octal-escape': 'warn',
		// 禁用 __proto__ 属性
		'no-proto': 'warn',
		// 禁止多次声明同一变量
		'no-redeclare': 'warn',
		// 禁止在 return 语句中使用赋值语句
		'no-return-assign': 'warn',
		// 禁用不必要的 return await
		'no-return-await': 'warn',
		// 禁止使用 javascript: url
		'no-script-url': 'warn',
		// 禁止自我赋值
		'no-self-assign': 'warn',
		// 禁止自身比较
		'no-self-compare': 'warn',
		// 禁用逗号操作符
		'no-sequences': 'warn',
		// 禁用一成不变的循环条件
		'no-unmodified-loop-condition': 'warn',
		// 禁用出现未使用过的标
		'no-unused-labels': 'warn',
		// 禁止不必要的 .call() 和 .apply()
		'no-useless-call': 'warn',
		// 禁止不必要的 catch 子句
		'no-useless-catch': 'warn',
		// 禁止不必要的字符串字面量或模板字面量的连接
		'no-useless-concat': 'warn',
		// 禁止多余的 return 语句
		'no-useless-return': 'warn',
		// 禁用 void 操作符
		'no-void': 'warn',
		// 禁用 with 语句
		'no-with': 'warn',
		// 禁止使用不带 await 表达式的 async 函数
		'require-await': 'warn',
		// 要求 IIFE 使用括号括起来
		'wrap-iife': 'warn',
		// 禁止将变量初始化为 undefined
		'no-undef-init': 'warn',
		// 禁止在变量定义之前使用它们
		'no-use-before-define': 'warn',
		// 要求箭头函数的参数使用圆括号
		'arrow-parens': 'warn',
		// 禁止修改 const 声明的变量
		'no-const-assign': 'warn',
		// 禁止类成员中出现重复的名称
		'no-dupe-class-members': 'warn',
		// 要求使用 let 或 const 而不是 var
		'no-var': 'warn',
		// 要求回调函数使用箭头函数
		'prefer-arrow-callback': 'warn',

		// 单单词组件名称不报错，此特殊，请自主手动规避html固有标签
		'vue/multi-word-component-names': 'off',
		// 禁止在计算属性中使用异步请求
		'vue/no-async-in-computed-properties': 'warn',
		// 禁止在data中使用计算属性
		'vue/no-computed-properties-in-data': 'warn',
		// 禁止在条件判断中使用同样的条件
		'vue/no-dupe-v-else-if': 'warn',
		// 禁止相同的属性no-v-text-v-html-on-component
		'vue/no-duplicate-attributes': 'warn',
		// 禁止模板中有无效的根元素
		'vue/no-multiple-template-root': 'warn',
		// 禁止修改父组件数据
		'vue/no-mutating-props': 'warn',
		// 禁止有未使用的组件引用
		'vue/no-unused-components': 'warn',
		// 禁止textarea里直接写值,请使用v-model,
		'vue/no-textarea-mustache': 'warn',
		// 禁止使用计算属性像使用方法那样
		'vue/no-use-computed-property-like-method': 'warn',
		// 禁止同时使用v-if和v-for
		'vue/no-use-v-if-with-v-for': 'warn',
		// 禁止在tmplate上写无用属性
		'vue/no-useless-template-attributes': 'warn',
		// 禁止使用v-html/v-text，xss漏洞
		'vue/no-v-text-v-html-on-component': 'warn',
		// 必须指定父组件属性类型
		'vue/require-prop-type-constructor': 'warn',
		// v-for必须带:key
		'vue/require-v-for-key': 'warn',
		// 父组件属性的默认值必须有确切值或函数返回
		'vue/require-valid-default-prop': 'warn',
		// 在函数中必须返回值
		'vue/return-in-computed-property': 'warn',
		// 多个绑定时，必须有明确的指定
		'vue/use-v-on-exact': 'warn',
		// 验证父组件属性
		'vue/valid-define-props': 'warn',
		// next-tick检测
		'vue/valid-next-tick': 'warn',
		// root根元素检测
		'vue/valid-template-root': 'warn',
		// v-bind-sync检测
		'vue/valid-v-bind-sync': 'warn',
		// v-bind检测
		'vue/valid-v-bind': 'warn',
		// v-cloak检测
		'vue/valid-v-cloak': 'warn',
		// v-else-if检测
		'vue/valid-v-else-if': 'warn',
		// v-else检测
		'vue/valid-v-else': 'warn',
		// v-for检测
		'vue/valid-v-for': 'warn',
		// v-if检测
		'vue/valid-v-if': 'warn',
		// v-mode检测
		'vue/valid-v-model': 'warn',
		// v-on检测
		'vue/valid-v-on': 'warn',
		// v-once检测
		'vue/valid-v-once': 'warn',
		// v-pre检测
		'vue/valid-v-pre': 'warn',
		// v-show检测
		'vue/valid-v-show': 'warn',
		// v-slot检测
		'vue/valid-v-slot': 'warn',
		// v-text检测
		'vue/valid-v-text': 'warn'
	},
	parserOptions: {
		parser: '@babel/eslint-parser'
	},
	globals: {
		process: 'readonly',
		module: 'readonly'
	}
}
